@@ -66,16 +66,20 @@ their Python 3 names and locations::
     import configparser
     import test.support
     from collections import UserList
+    from itertools import filterfalse
     # and other moved modules and definitions
 
-It also includes experimental backports for three stdlib packages from Py3
-that were heavily refactored versus Py2::
+It also includes backports for three stdlib packages from Py3 that were
+heavily refactored versus Py2::
     
     import html, html.entities, html.parser
-    import http, http.server, http.client, http.cookies, http.cookiejar
-    import urllib, urllib.parse, urllib.request, urllib.error
+    import http, http.client
 
-*Warning*: currently only html.* and http.client pass their test suites.
+These currently are not supported, but we may support them in the
+future::
+    
+    import http.server, http.cookies, http.cookiejar
+    import urllib, urllib.parse, urllib.request, urllib.error
 
 
 Explicit imports
@@ -168,7 +172,7 @@ else:
 
 __ver_major__ = 0
 __ver_minor__ = 3
-__ver_patch__ = 1
+__ver_patch__ = 2
 __ver_sub__ = ''
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
 
